@@ -1,27 +1,17 @@
 -- arch-tag: Command utilities main file
 {-# LANGUAGE CPP #-}
 {-
-Copyright (C) 2004-2006 John Goerzen <jgoerzen@complete.org>
+Copyright (c) 2004-2011 John Goerzen <jgoerzen@complete.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
+All rights reserved.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+For license and copyright information, see the file LICENSE
 -}
 
 {- |
    Module     : System.Cmd.Utils
-   Copyright  : Copyright (C) 2004-2006 John Goerzen
-   License    : GNU GPL, version 2 or above
+   Copyright  : Copyright (C) 2004-2011 John Goerzen
+   License    : BSD3
 
    Maintainer : John Goerzen <jgoerzen@complete.org>
    Stability  : provisional
@@ -118,6 +108,7 @@ import System.IO
 import System.IO.Error
 import Control.Concurrent(forkIO)
 import Control.Exception(finally)
+import qualified Control.Exception(try, IOException)
 
 data PipeMode = ReadFromPipe | WriteToPipe
 
@@ -179,11 +170,11 @@ hPipeFrom fp args =
        let childstuff = do dupTo (snd pipepair) stdOutput
                            closeFd (fst pipepair)
                            executeFile fp True args Nothing
-       p <- try (forkProcess childstuff)
+       p <- Control.Exception.try (forkProcess childstuff)
        -- parent
        pid <- case p of
                   Right x -> return x
-                  Left e -> warnFail "pipeFrom" fp args $
+                  Left (e :: Control.Exception.IOException) -> warnFail "pipeFrom" fp args $
                             "Error in fork: " ++ show e
        closeFd (snd pipepair)
        h <- fdToHandle (fst pipepair)
@@ -228,11 +219,11 @@ hPipeTo fp args =
        let childstuff = do dupTo (fst pipepair) stdInput
                            closeFd (snd pipepair)
                            executeFile fp True args Nothing
-       p <- try (forkProcess childstuff)
+       p <- Control.Exception.try (forkProcess childstuff)
        -- parent
        pid <- case p of
                    Right x -> return x
-                   Left e -> warnFail "pipeTo" fp args $
+                   Left (e :: Control.Exception.IOException) -> warnFail "pipeTo" fp args $
                              "Error in fork: " ++ show e
        closeFd (fst pipepair)
        h <- fdToHandle (snd pipepair)
@@ -284,11 +275,11 @@ hPipeBoth fp args =
                            dupTo (fst topair) stdInput
                            closeFd (snd topair)
                            executeFile fp True args Nothing
-       p <- try (forkProcess childstuff)
+       p <- Control.Exception.try (forkProcess childstuff)
        -- parent
        pid <- case p of
                    Right x -> return x
-                   Left e -> warnFail "pipeBoth" fp args $
+                   Left (e :: Control.Exception.IOException) -> warnFail "pipeBoth" fp args $
                              "Error in fork: " ++ show e
        closeFd (snd frompair)
        closeFd (fst topair)
@@ -556,10 +547,10 @@ pOpen3Raw pin pout perr fp args childfunc =
 -}
         in
         do
-        p <- try (forkProcess childstuff)
+        p <- Control.Exception.try (forkProcess childstuff)
         pid <- case p of
                 Right x -> return x
-                Left e -> fail ("Error in fork: " ++ (show e))
+                Left (e :: Control.Exception.IOException) -> fail ("Error in fork: " ++ (show e))
         return pid
 
 #endif
